mysql.exceptions.client.Version_Error

Package mysql :: Package exceptions :: Module client :: Class Version_Error |
[hide private]
[frames] | no frames]

# Class Version_Error

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Version_Error

A protocol mismatch resulted from attempting to connect to a server with a client library that uses a different protocol version. This can happen if you use a very old client library to connect to a new server that wasn't started with the --old-protocol option.

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`